---
title: '[릴리즈노트] 2024-07-05 업데이트'
category: 업데이트
tags:
  - API / SDK
  - 업데이트
searchTags:
  - Econtext
  - 위변조
  - 엑심베이
  - 업데이트
  - 릴리즈노트
datetime: 2024-07-07T15:00:00.000Z
---

<Callout title="2024년 7월 5일 API / SDK 업데이트 소식을 안내드립니다." />



## **기타 업데이트 사항**

<Tag text="결제 서비스 V1" />

✔️ 엑심베이 Econtext 결제 시 일부 건에 대한 결제 상태 처리 로직이 변경되었습니다.

결제 승인이 완료된 경우 브라우저 새로고침 등의 이유로 결제 프로세스가 비정상적으로 종료된 경우에도 결제 상태가 결제 완료로 유지됩니다.

<Tag text="결제 서비스 V1" />

✔️ 엑심베이 결제 시 금액 위변조가 발생하는 경우 결제 취소 처리되도록 변경되었습니다.

승인 결과 처리 단계에서 결제 요청 당시 결제 금액과 승인 결제 금액이 다른 경우 자동으로 결제 취소 됩니다.

[\[API/SDK 릴리즈노트\] 2024-07-05 업데이트 보러가기↗](https://developers.portone.io/release-notes/api-sdk/2024-07-04)
